AnimatedGridViewBuilder class

A widget for creating a grid view with various scroll animations applied to its items.

Inheritance

Constructors

AnimatedGridViewBuilder({Key? key, required int itemCount, required IndexedWidgetBuilder itemBuilder, ScrollWidgetAnimationType animationType = ScrollWidgetAnimationType.fadeOut, Duration? animationDuration = const Duration(milliseconds: 500), double itemDelay = 0.1, double? bounceAmplitude, Color? colorChangeHighlightColor, int? delay, SliverGridDelegate? gridDelegate, SliverChildDelegate? childrenDelegate, Axis? scrollDirection, ScrollController? controller, bool? reverse, bool? primary, bool? shrinkWrap, ScrollPhysics? physics, EdgeInsetsGeometry? padding})
Padding for the grid view.
const

Properties

animationDuration → Duration?
The type of animation to apply to the items.
final
animationType → ScrollWidgetAnimationType
The builder function for individual grid items.
final
bounceAmplitude → double?
Color used for highlighting during color change animation.
final
childrenDelegate → SliverChildDelegate?
Delegate for grid layout.
final
colorChangeHighlightColor → Color?
Delay between item animations.
final
controller → ScrollController?
The direction in which the grid scrolls.
final
delay → int?
Delegate for grid children.
final
gridDelegate → SliverGridDelegate?
Amplitude of bounce animation.
final
hashCode → int
The hash code for this object.
no setterinherited
itemBuilder → IndexedWidgetBuilder
The total number of items in the grid.
final
itemCount → int
final
itemDelay → double
Duration of the animation.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding → EdgeInsetsGeometry?
Physics for the scroll view.
final
physics → ScrollPhysics?
Shrink-wrap the grid.
final
primary → bool?
Reverse the scroll direction.
final
reverse → bool?
Controller for the scroll behavior.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection → Axis?
Delay before starting animations.
final
shrinkWrap → bool?
Set as the primary scroll view.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AnimatedGridViewBuilder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited